import assert from "assert";
import chalk from "chalk";
import { Runner } from "../runner.js";
export class CLIRunner extends Runner {
    constructor(d) {
        super({ concurrency: d.numCPUs });
        this._errored = false;
        this._startTimes = new WeakMap();
        this._d = d;
    }
    onTaskStart(task) {
        this._startTimes.set(task, Date.now());
        if (this._errored) {
            return; // Skip logging.
        }
        this._d.log(`Starting ${chalk.blue(task.options.name)}`);
    }
    onTaskFinish(task) {
        if (this._errored) {
            return; // Skip logging.
        }
        const took = Date.now() - checkDefined(this._startTimes.get(task));
        this._d.log(`Finished ${chalk.green(task.options.name)} in ${this._d.prettyMilliseconds(took)}`);
    }
    onTaskError(task, e) {
        if (this._errored) {
            return; // Skip logging.
        }
        this._errored = true;
        this._d.error(`Error in ${chalk.red(task.options.name)}\n${e}`);
    }
}
function checkDefined(value) {
    assert(value);
    return value;
}
//# sourceMappingURL=runner.js.map